==> Gbook-1.1.tar.gz: Gbook/function.admin_optionstab.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------


$smarty->assign('startform', $this->CreateFormStart ($id, 'updateoptions', $returnid));
$smarty->assign('endform', $this->CreateFormEnd ());

$userslist = Gbook_utils::GetUsers();
$selectedusers = (array)unserialize($this->GetPreference('send_notifications_to', ''));
$smarty->assign('send_notifications_to', $this->Lang('send_notifications_to'));
$smarty->assign('input_send_notifications_to', $this->CreateInputSelectList($id, 'send_notifications_to[]', $userslist, $selectedusers, 6));

$smarty->assign('max_spamrate_active', $this->Lang('max_spamrate_active'));
$smarty->assign('input_max_spamrate_active', $this->CreateInputText($id, 'max_spamrate_active', $this->GetPreference('max_spamrate_active', 0.6),5,5) . ' ' . $this->Lang('max_spamrate_active_help'));

$smarty->assign('max_spamrate_notify', $this->Lang('max_spamrate_notify'));
$smarty->assign('input_max_spamrate_notify', $this->CreateInputText($id, 'max_spamrate_notify', $this->GetPreference('max_spamrate_notify', 0.9),5,5) . ' ' . $this->Lang('max_spamrate_notify_help'));

$smarty->assign('max_spamrate_save', $this->Lang('max_spamrate_save'));
$smarty->assign('input_max_spamrate_save', $this->CreateInputText($id, 'max_spamrate_save', $this->GetPreference('max_spamrate_save', 0.9),5,5) . ' ' . $this->Lang('max_spamrate_save_help'));

$smarty->assign('badwords', $this->Lang('badwords'));
$smarty->assign('input_badwords', $this->	CreateTextArea (false, $id, $this->GetPreference('badwords', ''), 'badwords', '', '', '', '', 80, 5, '', '' , 'style="height:100px;"'));

$smarty->assign('submit', $this->CreateInputSubmit ($id, 'optionssubmitbutton', lang('submit')));

// Display the populated template
echo $this->ProcessTemplate ('adminoptions.tpl');

?>

==> Gbook-2.0.3.tar.gz: Gbook/function.admin_optionstab.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------


$smarty->assign('startform', $this->CreateFormStart ($id, 'updateoptions', $returnid));
$smarty->assign('endform', $this->CreateFormEnd ());

$smarty->assign('title_custom_modulename', $this->Lang('title_custom_modulename'));	
$smarty->assign('help_custom_modulename', $this->Lang('help_custom_modulename'));
$smarty->assign('input_custom_modulename',$this->CreateInputText($id, 'input_custom_modulename',$this->GetPreference('custom_modulename',''),50,255));

$smarty->assign('title_admin_section', $this->Lang('title_admin_section'));	
$smarty->assign('help_admin_section', $this->Lang('help_admin_section'));
$smarty->assign('input_admin_section', $this->CreateInputDropdown($id, 'input_admin_section',
				array(lang('main') => 'main',
							lang('content') => 'content',
							lang('layout') => 'layout',
							lang('usersgroups') => 'usersgroups',
							lang('extensions') => 'extensions',
							lang('myprefs') => 'myprefs'),
				-1,
				$this->GetPreference('admin_section', 'content')
));

$userslist = Gbook_utils::GetUsers();
$selectedusers = (array)unserialize($this->GetPreference('send_notifications_to', 's:0:"";'));
$smarty->assign('send_notifications_to', $this->Lang('send_notifications_to'));
$smarty->assign('input_send_notifications_to', $this->CreateInputSelectList($id, 'send_notifications_to[]', $userslist, $selectedusers, 6));

$smarty->assign('max_spamrate_active', $this->Lang('max_spamrate_active'));
$smarty->assign('input_max_spamrate_active', $this->CreateInputText($id, 'max_spamrate_active', $this->GetPreference('max_spamrate_active', 0.6),5,5) . ' ' . $this->Lang('max_spamrate_active_help'));

$smarty->assign('max_spamrate_notify', $this->Lang('max_spamrate_notify'));
$smarty->assign('input_max_spamrate_notify', $this->CreateInputText($id, 'max_spamrate_notify', $this->GetPreference('max_spamrate_notify', 0.9),5,5) . ' ' . $this->Lang('max_spamrate_notify_help'));

$smarty->assign('max_spamrate_save', $this->Lang('max_spamrate_save'));
$smarty->assign('input_max_spamrate_save', $this->CreateInputText($id, 'max_spamrate_save', $this->GetPreference('max_spamrate_save', 0.9),5,5) . ' ' . $this->Lang('max_spamrate_save_help'));

$smarty->assign('badwords', $this->Lang('badwords'));
$smarty->assign('input_badwords', $this->	CreateTextArea (false, $id, $this->GetPreference('badwords', ''), 'badwords', '', '', '', '', 80, 5, '', '' , 'style="height:100px;"'));

$smarty->assign('submit', $this->CreateInputSubmit ($id, 'optionssubmitbutton', lang('submit')));

// Display the populated template
echo $this->ProcessTemplate ('adminoptions.tpl');

?>
